@@ -1,5 +1,5 @@
-import json
 import uuid
+import jmespath
 
 
 class Instance(object):
@@ -37,28 +37,6 @@ class Instance(object):
         def default_value(name, value):
             return value
 
-        def get_attribute_from_dictionary(name: str, dictionary: dict):
-            sections = name.split(".")
-
-            if len(sections) == 1:
-                try:
-                    return dictionary[name]
-                except KeyError:
-                    raise AttributeError()
-
-            index = 1
-
-            while index < len(sections):
-                name = ".".join(sections[:-index])
-
-                if name in dictionary:
-                    attribute = ".".join(sections[-index:])
-                    return get_attribute_from_dictionary(attribute, dictionary[name])
-
-                index += 1
-
-            raise AttributeError()
-
         value = None
         attribute_doesnt_exist = raise_exception
         if "default" in kwargs:
@@ -71,32 +49,11 @@ class Instance(object):
         if name is None:
             return attribute_doesnt_exist(name, value)
 
-        if name == "prediction":
-            return self.prediction
+        expression = jmespath.search(name, self.to_dict())
+        if expression is None:
+            return attribute_doesnt_exist(name, value)
 
-        if name == "confidence":
-            return self.confidence
-
-        if name == "image":
-            return self.image
-
-        if name.startswith("metadata."):
-            try:
-                return get_attribute_from_dictionary(
-                    name[len("metadata.") :], self.metadata
-                )
-            except AttributeError:
-                return attribute_doesnt_exist(name, value)
-
-        if name.startswith("properties."):
-            try:
-                return get_attribute_from_dictionary(
-                    name[len("properties.") :], self.properties
-                )
-            except AttributeError:
-                return attribute_doesnt_exist(name, value)
-
-        return attribute_doesnt_exist(name, value)
+        return expression
 
     def to_dict(self):
         return self.__dict__
@@ -105,10 +62,14 @@ class Instance(object):
     def create(data):
         data = data.copy()
 
+        id = data.get("id", None)
         prediction = data.get("prediction", 1)
         confidence = data.get("confidence", 1.0)
         image = data.get("image", None)
 
+        if "id" in data:
+            del data["id"]
+
         if "prediction" in data:
             del data["prediction"]
 
@@ -118,10 +79,28 @@ class Instance(object):
         if "image" in data:
             del data["image"]
 
-        metadata = Instance._format(data)
+        if "metadata" in data:
+            metadata = data["metadata"]
+            del data["metadata"]
+        else:
+            metadata = {}
+
+        if "properties" in data:
+            properties = data["properties"]
+            del data["properties"]
+        else:
+            properties = {}
+
+        for key, value in data.items():
+            metadata[key] = value
 
         instance = Instance(
-            prediction=prediction, confidence=confidence, image=image, metadata=metadata
+            id=id,
+            prediction=prediction,
+            confidence=confidence,
+            image=image,
+            metadata=metadata,
+            properties=properties,
         )
 
         return instance
@@ -129,18 +108,7 @@ class Instance(object):
     @staticmethod
     def _format(data: dict) -> dict:
         for key, value in data.items():
-            if isinstance(value, dict):
-                data[key] = Instance._format(value)
-                continue
-
-            # ML Metadata exclusively supports int, float, and str values. Anything else
-            # we need to convert to a string.
-            if not (
-                isinstance(value, int)
-                or isinstance(value, float)
-                or isinstance(value, str)
-            ):
-                data[key] = json.dumps(value)
+            data[key] = value
 
         return data
 
