@@ -43,7 +43,7 @@ class Module(object):
             return None
 
 
-class Retriable(Module):
+class Connection(Module):
     def __init__(
         self,
         module_id=None,
@@ -56,3 +56,22 @@ class Retriable(Module):
         interval = 60
         self.schedule = schedule or [max_retries, interval]
 
+    def run(self, instance, **kwargs):
+        if not self.is_online():
+            raise ServiceException("No internet connection")
+
+    def is_online(self):
+        """
+        This function checks whether there's internet connection.
+        """
+
+        import http.client as httplib
+
+        connection = httplib.HTTPSConnection("8.8.8.8", timeout=5)
+        try:
+            connection.request("HEAD", "/")
+            return True
+        except Exception:
+            return False
+        finally:
+            connection.close()
