@@ -6,7 +6,7 @@ import boto3
 import requests
 
 from alira.instance import Instance
-from alira.modules.module import Retriable, ServiceException, Module
+from alira.modules.module import Connection, ServiceException, Module
 
 from botocore.exceptions import EndpointConnectionError
 
@@ -18,7 +18,7 @@ PIPELINE_EMAIL_MODULE_NAME = "email"
 PIPELINE_SMS_MODULE_NAME = "sms"
 
 
-class Notification(Retriable):
+class Notification(Connection):
     def __init__(
         self,
         module_id: str,
@@ -79,6 +79,8 @@ class EmailNotification(Notification):
         self.provider = provider or AwsSesEmailNotificationProvider(**kwargs)
 
     def run(self, instance: Instance, **kwargs) -> dict:
+        super().run(instance, **kwargs)
+
         if self.filtering and not self.filtering(instance):
             logging.info(
                 f"The instance didn't pass the filtering criteria. Instance: {instance}"
@@ -176,6 +178,8 @@ class SmsNotification(Notification):
         self.provider = provider or TwilioSmsNotificationProvider(**kwargs)
 
     def run(self, instance: Instance, **kwargs):
+        super().run(instance, **kwargs)
+
         if self.filtering and not self.filtering(instance):
             logging.info(
                 f"The instance didn't pass the filtering criteria. Instance: {instance}"
